#
# spec file for package cmake (Version 2.4.8)
#
# Copyright (c) 2007 SUSE LINUX Products GmbH, Nuernberg, Germany.
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#
# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

Name:           cmake
Version:        2.4.8
Release:        2.5
License:        BSD 3-Clause
Group:          Development/Tools/Building
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %suse_version > 1020
BuildRequires:  libexpat-devel
%else
BuildRequires:  expat
%endif
BuildRequires:  curl-devel expat gcc-c++ libstdc++-devel ncurses-devel zlib-devel
Url:            http://www.cmake.org/
Source0:        %{name}-%{version}.tar.gz
Patch0:         cmake-2.4.7-use_intree_xmlrpc.patch
Patch1:         cmake-2.4.7-less_verbosity.patch
Patch2:         cmake-2.4.7-use_shared_python_lib.patch
Summary:        Cross-platform, open-source make system

%description
CMake is a cross-platform, open-source make system



Authors:
--------
    Kitware, Inc., Insight Consortium

%prep
%setup -q -n %name-%version
%patch0
#disabled because it breaks progress information
#%patch1
%patch2

%build
export CXXFLAGS="$RPM_OPT_FLAGS"
export CFLAGS="$CXXFLAGS"
./configure \
    --prefix=%{_prefix} \
    --datadir=/share/%{name} \
    --docdir=/share/doc/packages/%{name} \
    --mandir=/share/man \
    --system-libs
make VERBOSE=1 %{?jobs:-j %jobs}

%install
make DESTDIR=%{buildroot} install
find %{buildroot}/usr/share/cmake -type f -print0 | xargs -0 chmod 644

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
/usr/bin/cpack
/usr/bin/ccmake
/usr/bin/cmake
/usr/bin/ctest
/usr/share/cmake
%doc /usr/share/doc/packages/%name
/usr/share/man/man1/ccmake.1.gz
/usr/share/man/man1/cmake.1.gz
/usr/share/man/man1/ctest.1.gz
%changelog
* Sat Apr 26 2008 cs@linux-administrator.com
- new upstream release 2.4.8
* Fri Sep 21 2007 dmueller@suse.de
- disabling less_verbosity patch
* Fri Jul 20 2007 pcerny@suse.cz
- update to 2.4.7 - several bugfixes
  (KDevelop problem among others,
  see ChangeLog.manual for more details)
* Fri Apr 27 2007 dmueller@suse.de
- expat -> libexpat-devel
* Thu Mar 29 2007 dmueller@suse.de
- add ncurses-devel buildrequires
* Thu Jan 11 2007 dmueller@suse.de
- update to 2.4.6:
  * Fix for FIND_* order and framworks with PREFIX usage.
  * Fix for FindDoxygen and quiet mode.
  * Find JavaVM as well as jvm
  * Look for ruby1.8 and ruby
  * Fix for cpack .tgz.sh and dash
  * Fix for finding custom commands from a full path with CMAKE_CFG_INTDIR.
  * Fix for Borland make and custom commands that do nothing
* Mon Jan  8 2007 dmueller@suse.de
- readd patch to detect shared python library instead of
  the static one.
* Tue Dec 19 2006 mrueckert@suse.de
- added cmake-2.4.5_use_intree_xmlrpc.patch:
  the xmlrpc-c check seems broken. and on 10.2 we dont have the lib
  anyways. so disable the systemwide xmlrpc for now.
* Fri Dec 15 2006 mrueckert@suse.de
- update to version 2.4.5:
  * Fix for seg fault when a macro runs a bad command BUG# 3815
  * Fix fix for foo.dll.lib that does not break -L/usr/lib in
    link names
  * Fix problem with LIBRARY_OUTPUT_PATH and linking to a dll
    foo.dll.lib instead of foo.lib
  * Do not depend on optimized libraries for a debug build and
    visa versa.
  * Fix target name matching custom command output conflict.
  * Fix FindQt3 so that it does not find qt4
  * Fix FindKDE4 so that it only looks for kde4-config
- disabled all patches -> applied upstream
* Mon Oct  2 2006 dmueller@suse.de
- detect shared python library instead of static variant
* Tue Sep 26 2006 dmueller@suse.de
- add python 2.5 support
* Sun Sep 10 2006 dmueller@suse.de
- build against system zlib / libcurl
* Mon Aug 28 2006 coolo@suse.de
- fix Qt3 configure check for lib64
* Sat Aug 26 2006 coolo@suse.de
- respect DESTDIR on installing kde3 icons
* Mon Aug 14 2006 coolo@suse.de
- add SUSE default paths for Qt3
* Mon Jul 31 2006 dmueller@suse.de
- 2.4.3 update:
  * progress is now reported with makefiles
  * Fix relative path problems in ADD_SUBDIRECTORY
  * Fix crash in CMakeSetup when status line is long
  * make sure try compile files have a newline at the end
  * add rxvt-unicode, cygwin, and screen terminal support for color
  output
* Thu May 18 2006 dmueller@suse.de
- 2.4.2 update:
  * Run symlink command from correct directory for executable versions
  * Fix for universal binaries and Xcode depend problem
  * Changes to LIST command, see --help-command LIST
  * Fix FindQT to be able to use full paths to source files
  * Fix CPack ZIP on windows command line problem
  * Find executables with no extension on windows mingw
  * Fix FindQt3 to use QTDIR over path
  * Significant speedup in try-compile for nmake
  * CPack improvements including tar bzip2
  * FindQt4 windows path fix
  * Sunos cc optimize flags are correct
  * Fix crash with ${} empty variable
  * Increase depend speed on Mac OS.
  * install command CONFIGURATIONS option.
  * Fix MSVC60, MSVC70, MSVC71, MSVC80 definitions for IDE builds
  * Fix for C++ compiler being used for c code in VS IDE
* Wed May 10 2006 dmueller@suse.de
- 2.4.1 update :
  * Several ctest and cpack bug fixes
  * Many updates and fixes for FindQt4.cmake
  * Fix CMAKE_REQUIRED_FLAGS in CheckCXXSourceCompiles.cmake
  * Handle running make from a symlinked build tree
  * Automatic color ouput detection for shells building with make
  * Kdevelop generator handles CMakeFiles directory better
  * add correct depend information for fluid
  * allow the cache to be saved even if a fatal error occurs
  * fix bug in relative path subdir and add_subdirectoy commands
  * support in vs for two object files with the same name
  * short file names used for library paths in visual studio
  * package target only shows up when you have cpack config files
  * Use dl and not -ldl for adding in the dynamic library
  * Fix check c/cxx source compiles macros to not clobber log files
  * Fix nmake version detection of cl and create correct pdb files
  * Fix msys bootstrap
  * Change color output to be more readable
  * Fix vs6 library naming
* Wed Apr 19 2006 dmueller@suse.de
- update to 2.4.0, fixes -L/-I compiler flag ordering
  needed for building KDE 4 trunk.
* Fri Apr 14 2006 dmueller@suse.de
- fix --help-modules / --help-module <module>
* Mon Mar 27 2006 dmueller@suse.de
- compile with RPM_OPT_FLAGS (#160857)
- fix permissions of installed files (#160856)
* Fri Mar 24 2006 dmueller@suse.de
- drop rpath patch, no longer necessary
* Mon Mar 20 2006 dmueller@suse.de
- CVS snapshot update, fixes RPATH handling
* Wed Feb 15 2006 dmueller@suse.de
- Initial package (2.3 CVS snapshot 20060210)
